@@ -4,10 +4,20 @@
 import inspect
 import invocation
 from mock_registry import mock_registry
+import warnings
 
-class Dummy(object): pass
+__copyright__ = "Copyright 2008-2010, Mockito Contributors"
+__license__ = "MIT"
+__maintainer__ = "Mockito Maintainers"
+__email__ = "mockito-python@googlegroups.com"
 
-class Mock(object):
+__all__ = ['mock', 'Mock']
+
+class _Dummy(object): pass
+
+class TestDouble(object): pass
+
+class mock(TestDouble):
   def __init__(self, mocked_obj=None, strict=True):
     self.invocations = []
     self.stubbed_invocations = []
@@ -15,7 +25,7 @@ class Mock(object):
     self.stubbing = None
     self.verification = None
     if mocked_obj is None:
-        mocked_obj = Dummy()
+        mocked_obj = _Dummy()
         strict = False
     self.mocked_obj = mocked_obj
     self.strict = strict
@@ -83,8 +93,11 @@ class Mock(object):
     while self.original_methods:  
       method_name, original_method = self.original_methods.pop()      
       self.set_method(method_name, original_method)
- 
-# Alias to make API similar to Java one.
-# Old name stays for compatibility.      
-mock = Mock
-
+       
+def Mock(*args, **kwargs):
+  '''A ``mock``() alias.
+  
+  Alias for compatibility. To be removed in version 1.0.
+  '''
+  warnings.warn("\n`Mock()` is deprecated, please use `mock()` (lower 'm') instead.", DeprecationWarning)
+  return mock(*args, **kwargs)
