@@ -1,13 +1,12 @@
 #!/usr/bin/env python
 # coding: utf-8
 
-import matchers
 import verification
-from mocking import Mock, mock
+from mocking import mock, TestDouble
 from mock_registry import mock_registry
 from verification import VerificationError
 
-__copyright__ = "Copyright 2009-2010, Mockito Contributors"
+__copyright__ = "Copyright 2008-2010, Mockito Contributors"
 __license__ = "MIT"
 __maintainer__ = "Mockito Maintainers"
 __email__ = "mockito-python@googlegroups.com"
@@ -47,27 +46,24 @@ def verify(obj, times=1, atleast=None, atmost=None, between=None, inorder=False)
                            e.g. [1, 4] or [0, 3] or [2, 2]
                            You wanted to set it to: %s""" % between)
 
-  if isinstance(obj, Mock):
-    mock = obj
+  if isinstance(obj, TestDouble):
+    mocked_object = obj
   else:
-    mock = mock_registry.mock_for(obj)
+    mocked_object = mock_registry.mock_for(obj)
                
   if atleast:
-    mock.verification = verification.AtLeast(atleast)
+    mocked_object.verification = verification.AtLeast(atleast)
   elif atmost:
-    mock.verification = verification.AtMost(atmost)
+    mocked_object.verification = verification.AtMost(atmost)
   elif between:
-    mock.verification = verification.Between(*between)
+    mocked_object.verification = verification.Between(*between)
   else:
-    mock.verification = verification.Times(times)
+    mocked_object.verification = verification.Times(times)
     
   if inorder:
-    mock.verification = verification.InOrder(mock.verification)
+    mocked_object.verification = verification.InOrder(mocked_object.verification)
     
-  return mock
-
-def times(count):
-  return count
+  return mocked_object
 
 def when(obj, strict=True):
   if isinstance(obj, mock):
@@ -92,14 +88,3 @@ def verifyNoMoreInteractions(*mocks):
       
 def verifyZeroInteractions(*mocks):
   verifyNoMoreInteractions(*mocks)
-      
-def any(wanted_type=None):
-  """Matches any() argument OR any(SomeClass) argument
-     Examples:
-       when(mock).foo(any()).thenReturn(1)
-       verify(mock).foo(any(int))
-  """
-  return matchers.Any(wanted_type)     
-        
-def contains(sub):
-  return matchers.Contains(sub)
